.. tutorials.bios documentation file, created by FIREWHEELs Model Component generation.
   You can adapt this file completely to your liking.

.. _tutorials.bios_mc:

##############
tutorials.bios
##############

This MC is used in the :ref:`bios-tutorial` to show how to modify a VM with a custom BIOS.
The ``INSTALL`` file will help download the necessary BIOS image.


**Attribute Provides:**
    * ``topology``

**Attribute Depends:**
    * ``graph``


**Model Component Dependencies:**
    * :ref:`base_objects_mc`
    * :ref:`linux.ubuntu1604_mc`


******
Plugin
******

.. automodule:: tutorials.bios_plugin
    :members:
    :undoc-members:
    :special-members:
    :private-members:
    :show-inheritance:
    :exclude-members: __dict__,__weakref__,__module__


